@@ -43,6 +43,7 @@ use uucore::display::Quotable;
 use uucore::error::{set_exit_code, strip_errno, UError, UResult, USimpleError, UUsageError};
 use uucore::line_ending::LineEnding;
 use uucore::parse_size::{ParseSizeError, Parser};
+use uucore::shortcut_value_parser::ShortcutValueParser;
 use uucore::version_cmp::version_cmp;
 use uucore::{format_usage, help_about, help_section, help_usage};
 
@@ -251,6 +252,7 @@ impl Output {
         let file = if let Some(name) = name {
             // This is different from `File::create()` because we don't truncate the output yet.
             // This allows using the output file as an input file.
+            #[allow(clippy::suspicious_open_options)]
             let file = OpenOptions::new()
                 .write(true)
                 .create(true)
@@ -985,7 +987,7 @@ impl FieldSelector {
                 let mut range = match to {
                     Some(Resolution::StartOfChar(mut to)) => {
                         // We need to include the character at `to`.
-                        to += line[to..].chars().next().map_or(1, |c| c.len_utf8());
+                        to += line[to..].chars().next().map_or(1, char::len_utf8);
                         from..to
                     }
                     Some(Resolution::EndOfChar(to)) => from..to,
@@ -1296,14 +1298,14 @@ pub fn uu_app() -> Command {
         .arg(
             Arg::new(options::modes::SORT)
                 .long(options::modes::SORT)
-                .value_parser([
+                .value_parser(ShortcutValueParser::new([
                     "general-numeric",
                     "human-numeric",
                     "month",
                     "numeric",
                     "version",
                     "random",
-                ])
+                ]))
                 .conflicts_with_all(options::modes::ALL_SORT_MODES),
         )
         .arg(make_sort_mode_arg(
@@ -1362,11 +1364,11 @@ pub fn uu_app() -> Command {
                 .long(options::check::CHECK)
                 .require_equals(true)
                 .num_args(0..)
-                .value_parser([
+                .value_parser(ShortcutValueParser::new([
                     options::check::SILENT,
                     options::check::QUIET,
                     options::check::DIAGNOSE_FIRST,
-                ])
+                ]))
                 .conflicts_with(options::OUTPUT)
                 .help("check for sorted input; do not sort"),
         )
