@@ -123,6 +123,15 @@ fn test_invalid_arg() {
     new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
 }
 
+#[test]
+fn test_split_non_existing_file() {
+    new_ucmd!()
+        .arg("non-existing")
+        .fails()
+        .code_is(1)
+        .stderr_is("split: cannot open 'non-existing' for reading: No such file or directory\n");
+}
+
 #[test]
 fn test_split_default() {
     let (at, mut ucmd) = at_and_ucmd!();
@@ -1068,6 +1077,7 @@ fn test_split_number_oversized_stdin() {
     new_ucmd!()
         .args(&["--number=3", "---io-blksize=600"])
         .pipe_in_fixture("sixhundredfiftyonebytes.txt")
+        .ignore_stdin_write_error()
         .fails()
         .stderr_only("split: -: cannot determine input size\n");
 }
